# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class AssemblyApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def assembly_add_revisions_to_assembly(self, assembly_id, revision_ids, **kwargs):  # noqa: E501
        """[Command] Add a list of revisions to an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_add_revisions_to_assembly(assembly_id, revision_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to add the revisions (required)
        :param list[str] revision_ids: A list of unique revision ids you want to add to the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_add_revisions_to_assembly_with_http_info(assembly_id, revision_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_add_revisions_to_assembly_with_http_info(assembly_id, revision_ids, **kwargs)  # noqa: E501
            return data

    def assembly_add_revisions_to_assembly_with_http_info(self, assembly_id, revision_ids, **kwargs):  # noqa: E501
        """[Command] Add a list of revisions to an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_add_revisions_to_assembly_with_http_info(assembly_id, revision_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to add the revisions (required)
        :param list[str] revision_ids: A list of unique revision ids you want to add to the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'revision_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_add_revisions_to_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_add_revisions_to_assembly`")  # noqa: E501
        # verify the required parameter 'revision_ids' is set
        if self.api_client.client_side_validation and ('revision_ids' not in params or
                                                       params['revision_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_ids` when calling `assembly_add_revisions_to_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'revision_ids' in params:
            body_params = params['revision_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/addrevisions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_add_tag(self, assembly_id, tag, **kwargs):  # noqa: E501
        """[Command] Add a search tag to an existing assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_add_tag(assembly_id, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly unique id (required)
        :param str tag: The tag to add to the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_add_tag_with_http_info(assembly_id, tag, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_add_tag_with_http_info(assembly_id, tag, **kwargs)  # noqa: E501
            return data

    def assembly_add_tag_with_http_info(self, assembly_id, tag, **kwargs):  # noqa: E501
        """[Command] Add a search tag to an existing assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_add_tag_with_http_info(assembly_id, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly unique id (required)
        :param str tag: The tag to add to the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_add_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_add_tag`")  # noqa: E501
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in params or
                                                       params['tag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag` when calling `assembly_add_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'tag' in params:
            body_params = params['tag']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/addtag', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_assemblies_link_to_run(self, run_id, **kwargs):  # noqa: E501
        """Get all the assemblies link to a run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_assemblies_link_to_run(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The run id you want the assemblies linked to (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_assemblies_link_to_run_with_http_info(run_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_assemblies_link_to_run_with_http_info(run_id, **kwargs)  # noqa: E501
            return data

    def assembly_assemblies_link_to_run_with_http_info(self, run_id, **kwargs):  # noqa: E501
        """Get all the assemblies link to a run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_assemblies_link_to_run_with_http_info(run_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The run id you want the assemblies linked to (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['run_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_assemblies_link_to_run" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `assembly_assemblies_link_to_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/run/{runId}/assemblies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Assembly]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_compare_assemblies(self, assembly_aid, assembly_bid, **kwargs):  # noqa: E501
        """[Command] Compare 2 assemblies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_compare_assemblies(assembly_aid, assembly_bid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_aid: Assembly A unique Id (required)
        :param str assembly_bid: Assembly B unique Id (required)
        :param CompareOptions compare_options: The import options. You can leave options empty.              By defaut, there will be no filter and no file export.              To apply a filter you have to fill ParametersSelectionFilters and ExcludeParametersInSelection.              To export a file you must fill OutPathFilePath. The file extension will be automatically replaced by the good one.              DiffGroup allows you to select the content of the diff file generated. You can choose A or B. By default B is selected.
        :return: list[CompareResultDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_compare_assemblies_with_http_info(assembly_aid, assembly_bid, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_compare_assemblies_with_http_info(assembly_aid, assembly_bid, **kwargs)  # noqa: E501
            return data

    def assembly_compare_assemblies_with_http_info(self, assembly_aid, assembly_bid, **kwargs):  # noqa: E501
        """[Command] Compare 2 assemblies  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_compare_assemblies_with_http_info(assembly_aid, assembly_bid, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_aid: Assembly A unique Id (required)
        :param str assembly_bid: Assembly B unique Id (required)
        :param CompareOptions compare_options: The import options. You can leave options empty.              By defaut, there will be no filter and no file export.              To apply a filter you have to fill ParametersSelectionFilters and ExcludeParametersInSelection.              To export a file you must fill OutPathFilePath. The file extension will be automatically replaced by the good one.              DiffGroup allows you to select the content of the diff file generated. You can choose A or B. By default B is selected.
        :return: list[CompareResultDetail]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_aid', 'assembly_bid', 'compare_options']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_compare_assemblies" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_aid' is set
        if self.api_client.client_side_validation and ('assembly_aid' not in params or
                                                       params['assembly_aid'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_aid` when calling `assembly_compare_assemblies`")  # noqa: E501
        # verify the required parameter 'assembly_bid' is set
        if self.api_client.client_side_validation and ('assembly_bid' not in params or
                                                       params['assembly_bid'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_bid` when calling `assembly_compare_assemblies`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'assembly_aid' in params:
            query_params.append(('assemblyAId', params['assembly_aid']))  # noqa: E501
        if 'assembly_bid' in params:
            query_params.append(('assemblyBId', params['assembly_bid']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'compare_options' in params:
            body_params = params['compare_options']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/compare', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CompareResultDetail]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_create_assembly(self, assembly, **kwargs):  # noqa: E501
        """Create an assembly. The revisions list content will be ignored. You have to call AddRevisionsToAssembly to add revisions to an assembly.  # noqa: E501

        Set Assembly.Id empty (00000000-0000-0000-0000-000000000000) in order to create a new assembly.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_create_assembly(assembly, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Assembly assembly: The assembly to create. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_create_assembly_with_http_info(assembly, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_create_assembly_with_http_info(assembly, **kwargs)  # noqa: E501
            return data

    def assembly_create_assembly_with_http_info(self, assembly, **kwargs):  # noqa: E501
        """Create an assembly. The revisions list content will be ignored. You have to call AddRevisionsToAssembly to add revisions to an assembly.  # noqa: E501

        Set Assembly.Id empty (00000000-0000-0000-0000-000000000000) in order to create a new assembly.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_create_assembly_with_http_info(assembly, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Assembly assembly: The assembly to create. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_create_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly' is set
        if self.api_client.client_side_validation and ('assembly' not in params or
                                                       params['assembly'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly` when calling `assembly_create_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'assembly' in params:
            body_params = params['assembly']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_delete_assembly(self, assembly_id, **kwargs):  # noqa: E501
        """Delete an assembly or group revision corresponding to a given id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_delete_assembly(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id or group revision you want to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_delete_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_delete_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_delete_assembly_with_http_info(self, assembly_id, **kwargs):  # noqa: E501
        """Delete an assembly or group revision corresponding to a given id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_delete_assembly_with_http_info(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id or group revision you want to delete (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_delete_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_delete_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_duplicate_assembly(self, assembly_id, **kwargs):  # noqa: E501
        """Duplicate an existing assembly. Set the flag \"withLogs\" to True to duplicate Logs as well.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_duplicate_assembly(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to copy. (required)
        :param bool with_logs: Flag indicating if the logs should also be duplicated.
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_duplicate_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_duplicate_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_duplicate_assembly_with_http_info(self, assembly_id, **kwargs):  # noqa: E501
        """Duplicate an existing assembly. Set the flag \"withLogs\" to True to duplicate Logs as well.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_duplicate_assembly_with_http_info(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to copy. (required)
        :param bool with_logs: Flag indicating if the logs should also be duplicated.
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'with_logs']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_duplicate_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_duplicate_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []
        if 'with_logs' in params:
            query_params.append(('withLogs', params['with_logs']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/duplicate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_export_assembly(self, assembly_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export an assembly into a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_export_assembly(assembly_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id corresponding to the assembly to export. (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : MyFile.m (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_export_assembly_with_http_info(assembly_id, output_file_path, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_export_assembly_with_http_info(assembly_id, output_file_path, **kwargs)  # noqa: E501
            return data

    def assembly_export_assembly_with_http_info(self, assembly_id, output_file_path, **kwargs):  # noqa: E501
        """[Command] Export an assembly into a file  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_export_assembly_with_http_info(assembly_id, output_file_path, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id corresponding to the assembly to export. (required)
        :param str output_file_path: The path to the file to create. You have to provide the file extension for example : MyFile.m (required)
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'output_file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_export_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_export_assembly`")  # noqa: E501
        # verify the required parameter 'output_file_path' is set
        if self.api_client.client_side_validation and ('output_file_path' not in params or
                                                       params['output_file_path'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `output_file_path` when calling `assembly_export_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []
        if 'output_file_path' in params:
            query_params.append(('outputFilePath', params['output_file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_get_assemblies(self, version_id, **kwargs):  # noqa: E501
        """Get all assemblies for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_assemblies(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: the version id to wich you want the assemblies. (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_get_assemblies_with_http_info(version_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_get_assemblies_with_http_info(version_id, **kwargs)  # noqa: E501
            return data

    def assembly_get_assemblies_with_http_info(self, version_id, **kwargs):  # noqa: E501
        """Get all assemblies for a given version  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_assemblies_with_http_info(version_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: the version id to wich you want the assemblies. (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_get_assemblies" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'version_id' is set
        if self.api_client.client_side_validation and ('version_id' not in params or
                                                       params['version_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `version_id` when calling `assembly_get_assemblies`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'version_id' in params:
            path_params['versionId'] = params['version_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/version/{versionId}/assemblies', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Assembly]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_get_assembly(self, assembly_id, **kwargs):  # noqa: E501
        """Get an assembly for a given id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_assembly(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: the unique id of the assembly. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_get_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_get_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_get_assembly_with_http_info(self, assembly_id, **kwargs):  # noqa: E501
        """Get an assembly for a given id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_assembly_with_http_info(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: the unique id of the assembly. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_get_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_get_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_get_current_assembly(self, **kwargs):  # noqa: E501
        """Get the current selected assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_current_assembly(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_get_current_assembly_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.assembly_get_current_assembly_with_http_info(**kwargs)  # noqa: E501
            return data

    def assembly_get_current_assembly_with_http_info(self, **kwargs):  # noqa: E501
        """Get the current selected assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_current_assembly_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_get_current_assembly" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/current', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_get_group_revisions_in_assembly_and_group(self, assembly_id, group_id, **kwargs):  # noqa: E501
        """Get a list of group revisions (sub assemblies linked to a group) setted to a given assembly and group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_group_revisions_in_assembly_and_group(assembly_id, group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id to which you search the linked group revisions (required)
        :param str group_id: The unique group id where the group revision are linked (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_get_group_revisions_in_assembly_and_group_with_http_info(assembly_id, group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_get_group_revisions_in_assembly_and_group_with_http_info(assembly_id, group_id, **kwargs)  # noqa: E501
            return data

    def assembly_get_group_revisions_in_assembly_and_group_with_http_info(self, assembly_id, group_id, **kwargs):  # noqa: E501
        """Get a list of group revisions (sub assemblies linked to a group) setted to a given assembly and group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_group_revisions_in_assembly_and_group_with_http_info(assembly_id, group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id to which you search the linked group revisions (required)
        :param str group_id: The unique group id where the group revision are linked (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'group_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_get_group_revisions_in_assembly_and_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_get_group_revisions_in_assembly_and_group`")  # noqa: E501
        # verify the required parameter 'group_id' is set
        if self.api_client.client_side_validation and ('group_id' not in params or
                                                       params['group_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `group_id` when calling `assembly_get_group_revisions_in_assembly_and_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/group/{groupId}/revisions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Assembly]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_get_group_revisions(self, assembly_id, **kwargs):  # noqa: E501
        """Get a list of group revisions (sub assemblies linked to a group) that are setted to a given assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_group_revisions(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id to which you search the linked group revisions (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_get_group_revisions_with_http_info(assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_get_group_revisions_with_http_info(assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_get_group_revisions_with_http_info(self, assembly_id, **kwargs):  # noqa: E501
        """Get a list of group revisions (sub assemblies linked to a group) that are setted to a given assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_get_group_revisions_with_http_info(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The unique assembly id to which you search the linked group revisions (required)
        :return: list[Assembly]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_get_group_revisions" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_get_group_revisions`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/grouprevisions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Assembly]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_import_assembly(self, **kwargs):  # noqa: E501
        """Create a new assembly by importing a definition file. This will also create the new revisions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_import_assembly(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the new assembly will belong
        :param str assembly_name: The assembly name to create
        :param str revision_name: The default revision name used to create the new revisions
        :param str file_path: The file path containing the parameters
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_import_assembly_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.assembly_import_assembly_with_http_info(**kwargs)  # noqa: E501
            return data

    def assembly_import_assembly_with_http_info(self, **kwargs):  # noqa: E501
        """Create a new assembly by importing a definition file. This will also create the new revisions.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_import_assembly_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str version_id: The version id to which the new assembly will belong
        :param str assembly_name: The assembly name to create
        :param str revision_name: The default revision name used to create the new revisions
        :param str file_path: The file path containing the parameters
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['version_id', 'assembly_name', 'revision_name', 'file_path']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_import_assembly" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'version_id' in params:
            query_params.append(('versionId', params['version_id']))  # noqa: E501
        if 'assembly_name' in params:
            query_params.append(('assemblyName', params['assembly_name']))  # noqa: E501
        if 'revision_name' in params:
            query_params.append(('revisionName', params['revision_name']))  # noqa: E501
        if 'file_path' in params:
            query_params.append(('filePath', params['file_path']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/import', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_link_run_to_assembly(self, run_id, assembly_id, **kwargs):  # noqa: E501
        """[Command] Link a run to an assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_link_run_to_assembly(run_id, assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The Id of the Run to link (required)
        :param str assembly_id: The Id of the Assembly to link (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_link_run_to_assembly_with_http_info(run_id, assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_link_run_to_assembly_with_http_info(run_id, assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_link_run_to_assembly_with_http_info(self, run_id, assembly_id, **kwargs):  # noqa: E501
        """[Command] Link a run to an assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_link_run_to_assembly_with_http_info(run_id, assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The Id of the Run to link (required)
        :param str assembly_id: The Id of the Assembly to link (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['run_id', 'assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_link_run_to_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `assembly_link_run_to_assembly`")  # noqa: E501
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_link_run_to_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501

        query_params = []
        if 'assembly_id' in params:
            query_params.append(('assemblyId', params['assembly_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/run/{runId}/linkassembly', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_lock_assembly(self, assembly_id, locked, **kwargs):  # noqa: E501
        """[Command] Lock an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_lock_assembly(assembly_id, locked, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to edit. (required)
        :param bool locked: True to lock the assembly, False to unlock (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_lock_assembly_with_http_info(assembly_id, locked, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_lock_assembly_with_http_info(assembly_id, locked, **kwargs)  # noqa: E501
            return data

    def assembly_lock_assembly_with_http_info(self, assembly_id, locked, **kwargs):  # noqa: E501
        """[Command] Lock an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_lock_assembly_with_http_info(assembly_id, locked, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to edit. (required)
        :param bool locked: True to lock the assembly, False to unlock (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'locked']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_lock_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_lock_assembly`")  # noqa: E501
        # verify the required parameter 'locked' is set
        if self.api_client.client_side_validation and ('locked' not in params or
                                                       params['locked'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `locked` when calling `assembly_lock_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []
        if 'locked' in params:
            query_params.append(('locked', params['locked']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/lock', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_remove_assembly_from_run(self, run_id, assembly_id, **kwargs):  # noqa: E501
        """[Command] Remove an assembly from a run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_assembly_from_run(run_id, assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The Id of the Run to unlink (required)
        :param str assembly_id: The Id of the Assembly to unlink (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_remove_assembly_from_run_with_http_info(run_id, assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_remove_assembly_from_run_with_http_info(run_id, assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_remove_assembly_from_run_with_http_info(self, run_id, assembly_id, **kwargs):  # noqa: E501
        """[Command] Remove an assembly from a run  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_assembly_from_run_with_http_info(run_id, assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str run_id: The Id of the Run to unlink (required)
        :param str assembly_id: The Id of the Assembly to unlink (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['run_id', 'assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_remove_assembly_from_run" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'run_id' is set
        if self.api_client.client_side_validation and ('run_id' not in params or
                                                       params['run_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `run_id` when calling `assembly_remove_assembly_from_run`")  # noqa: E501
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_remove_assembly_from_run`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'run_id' in params:
            path_params['runId'] = params['run_id']  # noqa: E501

        query_params = []
        if 'assembly_id' in params:
            query_params.append(('assemblyId', params['assembly_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/run/{runId}/unlinkassembly', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_remove_revisions_from_assembly(self, assembly_id, revision_ids, **kwargs):  # noqa: E501
        """[Command] Remove a list of revisions from an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_revisions_from_assembly(assembly_id, revision_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to remove the revisions (required)
        :param list[str] revision_ids: A list of unique revision ids to remove from the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_remove_revisions_from_assembly_with_http_info(assembly_id, revision_ids, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_remove_revisions_from_assembly_with_http_info(assembly_id, revision_ids, **kwargs)  # noqa: E501
            return data

    def assembly_remove_revisions_from_assembly_with_http_info(self, assembly_id, revision_ids, **kwargs):  # noqa: E501
        """[Command] Remove a list of revisions from an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_revisions_from_assembly_with_http_info(assembly_id, revision_ids, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to which you want to remove the revisions (required)
        :param list[str] revision_ids: A list of unique revision ids to remove from the assembly (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'revision_ids']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_remove_revisions_from_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_remove_revisions_from_assembly`")  # noqa: E501
        # verify the required parameter 'revision_ids' is set
        if self.api_client.client_side_validation and ('revision_ids' not in params or
                                                       params['revision_ids'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `revision_ids` when calling `assembly_remove_revisions_from_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'revision_ids' in params:
            body_params = params['revision_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/removerevisions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_remove_tag(self, assembly_id, tag, **kwargs):  # noqa: E501
        """[Command] Remove a search tag from an existing assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_tag(assembly_id, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly unique id (required)
        :param str tag: The tag to remove from the assembly (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_remove_tag_with_http_info(assembly_id, tag, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_remove_tag_with_http_info(assembly_id, tag, **kwargs)  # noqa: E501
            return data

    def assembly_remove_tag_with_http_info(self, assembly_id, tag, **kwargs):  # noqa: E501
        """[Command] Remove a search tag from an existing assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_remove_tag_with_http_info(assembly_id, tag, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly unique id (required)
        :param str tag: The tag to remove from the assembly (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'tag']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_remove_tag" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_remove_tag`")  # noqa: E501
        # verify the required parameter 'tag' is set
        if self.api_client.client_side_validation and ('tag' not in params or
                                                       params['tag'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `tag` when calling `assembly_remove_tag`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []
        if 'tag' in params:
            query_params.append(('tag', params['tag']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}/removetag', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_select_current_assembly(self, assembly_id, **kwargs):  # noqa: E501
        """[Command] Set the current selected assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_select_current_assembly(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to select (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_select_current_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_select_current_assembly_with_http_info(assembly_id, **kwargs)  # noqa: E501
            return data

    def assembly_select_current_assembly_with_http_info(self, assembly_id, **kwargs):  # noqa: E501
        """[Command] Set the current selected assembly  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_select_current_assembly_with_http_info(assembly_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id to select (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_select_current_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_select_current_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'assembly_id' in params:
            query_params.append(('assemblyId', params['assembly_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/current', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def assembly_update_assembly(self, assembly_id, assembly, **kwargs):  # noqa: E501
        """Update an assembly. The revisions list content will be ignored. You have to call AddRevisionsToAssembly to add revisions to an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_update_assembly(assembly_id, assembly, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id corresponding to the assembly you want to update. (required)
        :param Assembly assembly: The assembly to update. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assembly_update_assembly_with_http_info(assembly_id, assembly, **kwargs)  # noqa: E501
        else:
            (data) = self.assembly_update_assembly_with_http_info(assembly_id, assembly, **kwargs)  # noqa: E501
            return data

    def assembly_update_assembly_with_http_info(self, assembly_id, assembly, **kwargs):  # noqa: E501
        """Update an assembly. The revisions list content will be ignored. You have to call AddRevisionsToAssembly to add revisions to an assembly.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assembly_update_assembly_with_http_info(assembly_id, assembly, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str assembly_id: The assembly id corresponding to the assembly you want to update. (required)
        :param Assembly assembly: The assembly to update. (required)
        :return: Assembly
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['assembly_id', 'assembly']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assembly_update_assembly" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'assembly_id' is set
        if self.api_client.client_side_validation and ('assembly_id' not in params or
                                                       params['assembly_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly_id` when calling `assembly_update_assembly`")  # noqa: E501
        # verify the required parameter 'assembly' is set
        if self.api_client.client_side_validation and ('assembly' not in params or
                                                       params['assembly'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `assembly` when calling `assembly_update_assembly`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'assembly_id' in params:
            path_params['assemblyId'] = params['assembly_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'assembly' in params:
            body_params = params['assembly']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/assembly/{assemblyId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Assembly',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class Assembly(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'date_assembly': 'datetime',
        'version_id': 'str',
        'revision_list': 'list[str]',
        'description': 'str',
        'group_id': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'revision_last_update_date_utc': 'datetime',
        'revision_last_update_user': 'str',
        'is_locked': 'bool',
        'is_new': 'bool',
        'is_obsolete': 'bool',
        'is_partial': 'bool',
        'is_draft': 'bool',
        'global_assembly_tag': 'str',
        'tags': 'list[str]'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'date_assembly': 'DateAssembly',
        'version_id': 'VersionId',
        'revision_list': 'RevisionList',
        'description': 'Description',
        'group_id': 'GroupId',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'revision_last_update_date_utc': 'RevisionLastUpdateDateUtc',
        'revision_last_update_user': 'RevisionLastUpdateUser',
        'is_locked': 'IsLocked',
        'is_new': 'IsNew',
        'is_obsolete': 'IsObsolete',
        'is_partial': 'IsPartial',
        'is_draft': 'IsDraft',
        'global_assembly_tag': 'GlobalAssemblyTag',
        'tags': 'Tags'
    }

    def __init__(self, id=None, name=None, date_assembly=None, version_id=None, revision_list=None, description=None, group_id=None, last_update_date_utc=None, last_update_user=None, revision_last_update_date_utc=None, revision_last_update_user=None, is_locked=None, is_new=None, is_obsolete=None, is_partial=None, is_draft=None, global_assembly_tag=None, tags=None, _configuration=None):  # noqa: E501
        """Assembly - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._name = None
        self._date_assembly = None
        self._version_id = None
        self._revision_list = None
        self._description = None
        self._group_id = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._revision_last_update_date_utc = None
        self._revision_last_update_user = None
        self._is_locked = None
        self._is_new = None
        self._is_obsolete = None
        self._is_partial = None
        self._is_draft = None
        self._global_assembly_tag = None
        self._tags = None
        self.discriminator = None

        self.id = id
        self.name = name
        self.date_assembly = date_assembly
        self.version_id = version_id
        if revision_list is not None:
            self.revision_list = revision_list
        if description is not None:
            self.description = description
        if group_id is not None:
            self.group_id = group_id
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if revision_last_update_date_utc is not None:
            self.revision_last_update_date_utc = revision_last_update_date_utc
        if revision_last_update_user is not None:
            self.revision_last_update_user = revision_last_update_user
        if is_locked is not None:
            self.is_locked = is_locked
        if is_new is not None:
            self.is_new = is_new
        if is_obsolete is not None:
            self.is_obsolete = is_obsolete
        if is_partial is not None:
            self.is_partial = is_partial
        if is_draft is not None:
            self.is_draft = is_draft
        if global_assembly_tag is not None:
            self.global_assembly_tag = global_assembly_tag
        if tags is not None:
            self.tags = tags

    @property
    def id(self):
        """Gets the id of this Assembly.  # noqa: E501

        The unique assembly Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Assembly.  # noqa: E501

        :return: The id of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Assembly.

        The unique assembly Id.  Set the Id to Guid.Empty (00000000-0000-0000-0000-000000000000) if you want to create a new Assembly.  # noqa: E501

        :param id: The id of this Assembly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Assembly.  # noqa: E501

        The assembly name  # noqa: E501

        :return: The name of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Assembly.

        The assembly name  # noqa: E501

        :param name: The name of this Assembly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def date_assembly(self):
        """Gets the date_assembly of this Assembly.  # noqa: E501

        The creation date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :return: The date_assembly of this Assembly.  # noqa: E501
        :rtype: datetime
        """
        return self._date_assembly

    @date_assembly.setter
    def date_assembly(self, date_assembly):
        """Sets the date_assembly of this Assembly.

        The creation date.  The date must be an UTC date time. Here is an example : 2018-06-05T12:36:34.168Z  # noqa: E501

        :param date_assembly: The date_assembly of this Assembly.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and date_assembly is None:
            raise ValueError("Invalid value for `date_assembly`, must not be `None`")  # noqa: E501

        self._date_assembly = date_assembly

    @property
    def version_id(self):
        """Gets the version_id of this Assembly.  # noqa: E501

        The version to which the assembly belongs to  # noqa: E501

        :return: The version_id of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this Assembly.

        The version to which the assembly belongs to  # noqa: E501

        :param version_id: The version_id of this Assembly.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")  # noqa: E501

        self._version_id = version_id

    @property
    def revision_list(self):
        """Gets the revision_list of this Assembly.  # noqa: E501

        The revision ids associated to the assembly  # noqa: E501

        :return: The revision_list of this Assembly.  # noqa: E501
        :rtype: list[str]
        """
        return self._revision_list

    @revision_list.setter
    def revision_list(self, revision_list):
        """Sets the revision_list of this Assembly.

        The revision ids associated to the assembly  # noqa: E501

        :param revision_list: The revision_list of this Assembly.  # noqa: E501
        :type: list[str]
        """

        self._revision_list = revision_list

    @property
    def description(self):
        """Gets the description of this Assembly.  # noqa: E501

        The assembly description  # noqa: E501

        :return: The description of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Assembly.

        The assembly description  # noqa: E501

        :param description: The description of this Assembly.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def group_id(self):
        """Gets the group_id of this Assembly.  # noqa: E501

        If the assembly represents a group revision: the group id to which belongs the group revision.  Otherwise leave the property to Guid.Empty : 00000000-0000-0000-0000-000000000000  # noqa: E501

        :return: The group_id of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this Assembly.

        If the assembly represents a group revision: the group id to which belongs the group revision.  Otherwise leave the property to Guid.Empty : 00000000-0000-0000-0000-000000000000  # noqa: E501

        :param group_id: The group_id of this Assembly.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this Assembly.  # noqa: E501

        The last utc date time when the properties of the assembly have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_date_utc of this Assembly.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this Assembly.

        The last utc date time when the properties of the assembly have been updated.  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this Assembly.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this Assembly.  # noqa: E501

        The name of the last user having updated the assembly  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The last_update_user of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this Assembly.

        The name of the last user having updated the assembly  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param last_update_user: The last_update_user of this Assembly.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def revision_last_update_date_utc(self):
        """Gets the revision_last_update_date_utc of this Assembly.  # noqa: E501

        The last utc date time when the revisions list has been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The revision_last_update_date_utc of this Assembly.  # noqa: E501
        :rtype: datetime
        """
        return self._revision_last_update_date_utc

    @revision_last_update_date_utc.setter
    def revision_last_update_date_utc(self, revision_last_update_date_utc):
        """Sets the revision_last_update_date_utc of this Assembly.

        The last utc date time when the revisions list has been updated  This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param revision_last_update_date_utc: The revision_last_update_date_utc of this Assembly.  # noqa: E501
        :type: datetime
        """

        self._revision_last_update_date_utc = revision_last_update_date_utc

    @property
    def revision_last_update_user(self):
        """Gets the revision_last_update_user of this Assembly.  # noqa: E501

        The name of the last user having updated the revisions list   This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :return: The revision_last_update_user of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._revision_last_update_user

    @revision_last_update_user.setter
    def revision_last_update_user(self, revision_last_update_user):
        """Sets the revision_last_update_user of this Assembly.

        The name of the last user having updated the revisions list   This field will be automatically updated from the server side each time you update the object.  # noqa: E501

        :param revision_last_update_user: The revision_last_update_user of this Assembly.  # noqa: E501
        :type: str
        """

        self._revision_last_update_user = revision_last_update_user

    @property
    def is_locked(self):
        """Gets the is_locked of this Assembly.  # noqa: E501

        Return true if the assembly is locked  # noqa: E501

        :return: The is_locked of this Assembly.  # noqa: E501
        :rtype: bool
        """
        return self._is_locked

    @is_locked.setter
    def is_locked(self, is_locked):
        """Sets the is_locked of this Assembly.

        Return true if the assembly is locked  # noqa: E501

        :param is_locked: The is_locked of this Assembly.  # noqa: E501
        :type: bool
        """

        self._is_locked = is_locked

    @property
    def is_new(self):
        """Gets the is_new of this Assembly.  # noqa: E501

        Return true if the assembly is new  # noqa: E501

        :return: The is_new of this Assembly.  # noqa: E501
        :rtype: bool
        """
        return self._is_new

    @is_new.setter
    def is_new(self, is_new):
        """Sets the is_new of this Assembly.

        Return true if the assembly is new  # noqa: E501

        :param is_new: The is_new of this Assembly.  # noqa: E501
        :type: bool
        """

        self._is_new = is_new

    @property
    def is_obsolete(self):
        """Gets the is_obsolete of this Assembly.  # noqa: E501

        Return true if the assembly is obsolete  # noqa: E501

        :return: The is_obsolete of this Assembly.  # noqa: E501
        :rtype: bool
        """
        return self._is_obsolete

    @is_obsolete.setter
    def is_obsolete(self, is_obsolete):
        """Sets the is_obsolete of this Assembly.

        Return true if the assembly is obsolete  # noqa: E501

        :param is_obsolete: The is_obsolete of this Assembly.  # noqa: E501
        :type: bool
        """

        self._is_obsolete = is_obsolete

    @property
    def is_partial(self):
        """Gets the is_partial of this Assembly.  # noqa: E501

        Return true if the assembly is partial  # noqa: E501

        :return: The is_partial of this Assembly.  # noqa: E501
        :rtype: bool
        """
        return self._is_partial

    @is_partial.setter
    def is_partial(self, is_partial):
        """Sets the is_partial of this Assembly.

        Return true if the assembly is partial  # noqa: E501

        :param is_partial: The is_partial of this Assembly.  # noqa: E501
        :type: bool
        """

        self._is_partial = is_partial

    @property
    def is_draft(self):
        """Gets the is_draft of this Assembly.  # noqa: E501

        Return true if the assembly is draft  # noqa: E501

        :return: The is_draft of this Assembly.  # noqa: E501
        :rtype: bool
        """
        return self._is_draft

    @is_draft.setter
    def is_draft(self, is_draft):
        """Sets the is_draft of this Assembly.

        Return true if the assembly is draft  # noqa: E501

        :param is_draft: The is_draft of this Assembly.  # noqa: E501
        :type: bool
        """

        self._is_draft = is_draft

    @property
    def global_assembly_tag(self):
        """Gets the global_assembly_tag of this Assembly.  # noqa: E501

        Obsolete: No longer used anymore. Return the global export tag  # noqa: E501

        :return: The global_assembly_tag of this Assembly.  # noqa: E501
        :rtype: str
        """
        return self._global_assembly_tag

    @global_assembly_tag.setter
    def global_assembly_tag(self, global_assembly_tag):
        """Sets the global_assembly_tag of this Assembly.

        Obsolete: No longer used anymore. Return the global export tag  # noqa: E501

        :param global_assembly_tag: The global_assembly_tag of this Assembly.  # noqa: E501
        :type: str
        """

        self._global_assembly_tag = global_assembly_tag

    @property
    def tags(self):
        """Gets the tags of this Assembly.  # noqa: E501

        Return the list of tags used to perform research on assemblies  # noqa: E501

        :return: The tags of this Assembly.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Assembly.

        Return the list of tags used to perform research on assemblies  # noqa: E501

        :param tags: The tags of this Assembly.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Assembly, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Assembly):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Assembly):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package
from teamdbapi.api.assembly_api import AssemblyApi
from teamdbapi.api.car_api import CarApi
from teamdbapi.api.config_api import ConfigApi
from teamdbapi.api.edit_api import EditApi
from teamdbapi.api.event_api import EventApi
from teamdbapi.api.fixed_field_api import FixedFieldApi
from teamdbapi.api.group_api import GroupApi
from teamdbapi.api.import_export_api import ImportExportApi
from teamdbapi.api.lap_api import LapApi
from teamdbapi.api.lap_report_api import LapReportApi
from teamdbapi.api.model_field_api import ModelFieldApi
from teamdbapi.api.notes_authorization_api import NotesAuthorizationApi
from teamdbapi.api.parameter_api import ParameterApi
from teamdbapi.api.report_api import ReportApi
from teamdbapi.api.revision_api import RevisionApi
from teamdbapi.api.revision_editor_selector_api import RevisionEditorSelectorApi
from teamdbapi.api.run_api import RunApi
from teamdbapi.api.script_api import ScriptApi
from teamdbapi.api.session_api import SessionApi
from teamdbapi.api.target_api import TargetApi
from teamdbapi.api.team_db_list_api import TeamDBListApi
from teamdbapi.api.team_db_view_api import TeamDBViewApi
from teamdbapi.api.tire_api import TireApi
from teamdbapi.api.tire_set_api import TireSetApi
from teamdbapi.api.track_api import TrackApi
from teamdbapi.api.track_layout_api import TrackLayoutApi
from teamdbapi.api.user_api import UserApi
from teamdbapi.api.value_field_api import ValueFieldApi
from teamdbapi.api.version_api import VersionApi

# import ApiClient
from teamdbapi.api_client import ApiClient
from teamdbapi.configuration import Configuration
# import models into sdk package
from teamdbapi.models.assembly import Assembly
from teamdbapi.models.bleed_adjustment import BleedAdjustment
from teamdbapi.models.calibration import Calibration
from teamdbapi.models.car import Car
from teamdbapi.models.car_parameters_context import CarParametersContext
from teamdbapi.models.compare_options import CompareOptions
from teamdbapi.models.compare_result import CompareResult
from teamdbapi.models.compare_result_detail import CompareResultDetail
from teamdbapi.models.copy_from_tags_args import CopyFromTagsArgs
from teamdbapi.models.couple_guid_text import CoupleGuidText
from teamdbapi.models.event import Event
from teamdbapi.models.fixed_field import FixedField
from teamdbapi.models.group import Group
from teamdbapi.models.import_parameters_args import ImportParametersArgs
from teamdbapi.models.import_parameters_results import ImportParametersResults
from teamdbapi.models.item_value import ItemValue
from teamdbapi.models.item_value_key import ItemValueKey
from teamdbapi.models.lap import Lap
from teamdbapi.models.lap_report_options import LapReportOptions
from teamdbapi.models.model_field import ModelField
from teamdbapi.models.model_field_authorization import ModelFieldAuthorization
from teamdbapi.models.notes_authorization import NotesAuthorization
from teamdbapi.models.notes_context import NotesContext
from teamdbapi.models.parameter import Parameter
from teamdbapi.models.problem_details import ProblemDetails
from teamdbapi.models.revision import Revision
from teamdbapi.models.run import Run
from teamdbapi.models.script import Script
from teamdbapi.models.session import Session
from teamdbapi.models.string_with_font_style import StringWithFontStyle
from teamdbapi.models.target import Target
from teamdbapi.models.team_db_list import TeamDBList
from teamdbapi.models.team_db_list_item import TeamDBListItem
from teamdbapi.models.tire import Tire
from teamdbapi.models.tire_set import TireSet
from teamdbapi.models.track import Track
from teamdbapi.models.track_layout import TrackLayout
from teamdbapi.models.user import User
from teamdbapi.models.user_group import UserGroup
from teamdbapi.models.value_field import ValueField
from teamdbapi.models.version import Version



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from teamdbapi.api_client import ApiClient


class FixedFieldApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def fixed_field_get_fixed_field(self, fixed_field_id, **kwargs):  # noqa: E501
        """Get a fixed field via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_field(fixed_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str fixed_field_id: The unique fixed field id for which you want to get the fixed field (required)
        :return: FixedField
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.fixed_field_get_fixed_field_with_http_info(fixed_field_id, **kwargs)  # noqa: E501
        else:
            (data) = self.fixed_field_get_fixed_field_with_http_info(fixed_field_id, **kwargs)  # noqa: E501
            return data

    def fixed_field_get_fixed_field_with_http_info(self, fixed_field_id, **kwargs):  # noqa: E501
        """Get a fixed field via a unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_field_with_http_info(fixed_field_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str fixed_field_id: The unique fixed field id for which you want to get the fixed field (required)
        :return: FixedField
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fixed_field_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fixed_field_get_fixed_field" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'fixed_field_id' is set
        if self.api_client.client_side_validation and ('fixed_field_id' not in params or
                                                       params['fixed_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `fixed_field_id` when calling `fixed_field_get_fixed_field`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'fixed_field_id' in params:
            path_params['fixedFieldId'] = params['fixed_field_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/fixedfield/{fixedFieldId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FixedField',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fixed_field_get_fixed_field_value(self, fixed_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get a fixed field value via its unique id and and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_field_value(fixed_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str fixed_field_id: The unique fixed field id for which you want to get the fixed field value (required)
        :param str parent_item_id: The parent item id for which you want to get the fixed field value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.fixed_field_get_fixed_field_value_with_http_info(fixed_field_id, parent_item_id, **kwargs)  # noqa: E501
        else:
            (data) = self.fixed_field_get_fixed_field_value_with_http_info(fixed_field_id, parent_item_id, **kwargs)  # noqa: E501
            return data

    def fixed_field_get_fixed_field_value_with_http_info(self, fixed_field_id, parent_item_id, **kwargs):  # noqa: E501
        """Get a fixed field value via its unique id and and a parent entity unique id.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_field_value_with_http_info(fixed_field_id, parent_item_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str fixed_field_id: The unique fixed field id for which you want to get the fixed field value (required)
        :param str parent_item_id: The parent item id for which you want to get the fixed field value (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['fixed_field_id', 'parent_item_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fixed_field_get_fixed_field_value" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'fixed_field_id' is set
        if self.api_client.client_side_validation and ('fixed_field_id' not in params or
                                                       params['fixed_field_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `fixed_field_id` when calling `fixed_field_get_fixed_field_value`")  # noqa: E501
        # verify the required parameter 'parent_item_id' is set
        if self.api_client.client_side_validation and ('parent_item_id' not in params or
                                                       params['parent_item_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `parent_item_id` when calling `fixed_field_get_fixed_field_value`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'fixed_field_id' in params:
            path_params['fixedFieldId'] = params['fixed_field_id']  # noqa: E501

        query_params = []
        if 'parent_item_id' in params:
            query_params.append(('parentItemId', params['parent_item_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/fixedfield/{fixedFieldId}/value', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fixed_field_get_fixed_fields(self, field_type, **kwargs):  # noqa: E501
        """Get the list of all fixed fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_fields(field_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_type: The field type for which to return the fixed fields. (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.fixed_field_get_fixed_fields_with_http_info(field_type, **kwargs)  # noqa: E501
        else:
            (data) = self.fixed_field_get_fixed_fields_with_http_info(field_type, **kwargs)  # noqa: E501
            return data

    def fixed_field_get_fixed_fields_with_http_info(self, field_type, **kwargs):  # noqa: E501
        """Get the list of all fixed fields.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fixed_field_get_fixed_fields_with_http_info(field_type, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str field_type: The field type for which to return the fixed fields. (required)
        :return: list[CoupleGuidText]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['field_type']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fixed_field_get_fixed_fields" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'field_type' is set
        if self.api_client.client_side_validation and ('field_type' not in params or
                                                       params['field_type'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `field_type` when calling `fixed_field_get_fixed_fields`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'field_type' in params:
            path_params['fieldType'] = params['field_type']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/teamdbapi/v2.0/fixedfields/{fieldType}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CoupleGuidText]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Trackside Software TeamDB API v2.0

    This API enables you to access TeamDB data  # noqa: E501

    OpenAPI spec version: 2.0
    Contact: support@trackside.fr
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from teamdbapi.configuration import Configuration


class TireSet(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'event_id': 'str',
        'name': 'str',
        'comment': 'str',
        'id_fr': 'str',
        'id_fl': 'str',
        'id_rr': 'str',
        'id_rl': 'str',
        'mounting_direction_fl': 'str',
        'mounting_direction_fr': 'str',
        'mounting_direction_rl': 'str',
        'mounting_direction_rr': 'str',
        'last_update_date_utc': 'datetime',
        'last_update_user': 'str',
        'tire_set_color': 'str',
        'heating_time_of_use': 'datetime',
        'heating_duration': 'float',
        'heating_temperature': 'str',
        'heating_oven': 'StringWithFontStyle',
        'heating_engineer_comment': 'StringWithFontStyle',
        'heating_time_on_heat': 'datetime',
        'heating_tire_comment': 'StringWithFontStyle',
        'heating_action_after_use': 'str',
        'heating_done': 'bool',
        'id_spare1': 'str',
        'id_spare2': 'str'
    }

    attribute_map = {
        'id': 'Id',
        'event_id': 'EventId',
        'name': 'Name',
        'comment': 'Comment',
        'id_fr': 'IdFR',
        'id_fl': 'IdFL',
        'id_rr': 'IdRR',
        'id_rl': 'IdRL',
        'mounting_direction_fl': 'MountingDirectionFL',
        'mounting_direction_fr': 'MountingDirectionFR',
        'mounting_direction_rl': 'MountingDirectionRL',
        'mounting_direction_rr': 'MountingDirectionRR',
        'last_update_date_utc': 'LastUpdateDateUtc',
        'last_update_user': 'LastUpdateUser',
        'tire_set_color': 'TireSetColor',
        'heating_time_of_use': 'HeatingTimeOfUse',
        'heating_duration': 'HeatingDuration',
        'heating_temperature': 'HeatingTemperature',
        'heating_oven': 'HeatingOven',
        'heating_engineer_comment': 'HeatingEngineerComment',
        'heating_time_on_heat': 'HeatingTimeOnHeat',
        'heating_tire_comment': 'HeatingTireComment',
        'heating_action_after_use': 'HeatingActionAfterUse',
        'heating_done': 'HeatingDone',
        'id_spare1': 'IdSpare1',
        'id_spare2': 'IdSpare2'
    }

    def __init__(self, id=None, event_id=None, name=None, comment=None, id_fr=None, id_fl=None, id_rr=None, id_rl=None, mounting_direction_fl=None, mounting_direction_fr=None, mounting_direction_rl=None, mounting_direction_rr=None, last_update_date_utc=None, last_update_user=None, tire_set_color=None, heating_time_of_use=None, heating_duration=None, heating_temperature=None, heating_oven=None, heating_engineer_comment=None, heating_time_on_heat=None, heating_tire_comment=None, heating_action_after_use=None, heating_done=None, id_spare1=None, id_spare2=None, _configuration=None):  # noqa: E501
        """TireSet - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._event_id = None
        self._name = None
        self._comment = None
        self._id_fr = None
        self._id_fl = None
        self._id_rr = None
        self._id_rl = None
        self._mounting_direction_fl = None
        self._mounting_direction_fr = None
        self._mounting_direction_rl = None
        self._mounting_direction_rr = None
        self._last_update_date_utc = None
        self._last_update_user = None
        self._tire_set_color = None
        self._heating_time_of_use = None
        self._heating_duration = None
        self._heating_temperature = None
        self._heating_oven = None
        self._heating_engineer_comment = None
        self._heating_time_on_heat = None
        self._heating_tire_comment = None
        self._heating_action_after_use = None
        self._heating_done = None
        self._id_spare1 = None
        self._id_spare2 = None
        self.discriminator = None

        self.id = id
        self.event_id = event_id
        self.name = name
        if comment is not None:
            self.comment = comment
        if id_fr is not None:
            self.id_fr = id_fr
        if id_fl is not None:
            self.id_fl = id_fl
        if id_rr is not None:
            self.id_rr = id_rr
        if id_rl is not None:
            self.id_rl = id_rl
        if mounting_direction_fl is not None:
            self.mounting_direction_fl = mounting_direction_fl
        if mounting_direction_fr is not None:
            self.mounting_direction_fr = mounting_direction_fr
        if mounting_direction_rl is not None:
            self.mounting_direction_rl = mounting_direction_rl
        if mounting_direction_rr is not None:
            self.mounting_direction_rr = mounting_direction_rr
        if last_update_date_utc is not None:
            self.last_update_date_utc = last_update_date_utc
        if last_update_user is not None:
            self.last_update_user = last_update_user
        if tire_set_color is not None:
            self.tire_set_color = tire_set_color
        if heating_time_of_use is not None:
            self.heating_time_of_use = heating_time_of_use
        if heating_duration is not None:
            self.heating_duration = heating_duration
        if heating_temperature is not None:
            self.heating_temperature = heating_temperature
        if heating_oven is not None:
            self.heating_oven = heating_oven
        if heating_engineer_comment is not None:
            self.heating_engineer_comment = heating_engineer_comment
        if heating_time_on_heat is not None:
            self.heating_time_on_heat = heating_time_on_heat
        if heating_tire_comment is not None:
            self.heating_tire_comment = heating_tire_comment
        if heating_action_after_use is not None:
            self.heating_action_after_use = heating_action_after_use
        if heating_done is not None:
            self.heating_done = heating_done
        if id_spare1 is not None:
            self.id_spare1 = id_spare1
        if id_spare2 is not None:
            self.id_spare2 = id_spare2

    @property
    def id(self):
        """Gets the id of this TireSet.  # noqa: E501

        Unique identifier of the tire set  # noqa: E501

        :return: The id of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TireSet.

        Unique identifier of the tire set  # noqa: E501

        :param id: The id of this TireSet.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def event_id(self):
        """Gets the event_id of this TireSet.  # noqa: E501

        Unique identifier corresponding to the event to which the tire set belongs  # noqa: E501

        :return: The event_id of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._event_id

    @event_id.setter
    def event_id(self, event_id):
        """Sets the event_id of this TireSet.

        Unique identifier corresponding to the event to which the tire set belongs  # noqa: E501

        :param event_id: The event_id of this TireSet.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and event_id is None:
            raise ValueError("Invalid value for `event_id`, must not be `None`")  # noqa: E501

        self._event_id = event_id

    @property
    def name(self):
        """Gets the name of this TireSet.  # noqa: E501

        Tire set name  # noqa: E501

        :return: The name of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TireSet.

        Tire set name  # noqa: E501

        :param name: The name of this TireSet.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501
        if (self._configuration.client_side_validation and
                name is not None and len(name) < 1):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `1`")  # noqa: E501

        self._name = name

    @property
    def comment(self):
        """Gets the comment of this TireSet.  # noqa: E501

        Tire set comments  # noqa: E501

        :return: The comment of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this TireSet.

        Tire set comments  # noqa: E501

        :param comment: The comment of this TireSet.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def id_fr(self):
        """Gets the id_fr of this TireSet.  # noqa: E501

        Unique identifier corresponding to the front right tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_fr of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_fr

    @id_fr.setter
    def id_fr(self, id_fr):
        """Sets the id_fr of this TireSet.

        Unique identifier corresponding to the front right tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_fr: The id_fr of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_fr = id_fr

    @property
    def id_fl(self):
        """Gets the id_fl of this TireSet.  # noqa: E501

        Unique identifier corresponding to the front left tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_fl of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_fl

    @id_fl.setter
    def id_fl(self, id_fl):
        """Sets the id_fl of this TireSet.

        Unique identifier corresponding to the front left tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_fl: The id_fl of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_fl = id_fl

    @property
    def id_rr(self):
        """Gets the id_rr of this TireSet.  # noqa: E501

        Unique identifier corresponding to the rear right tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_rr of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_rr

    @id_rr.setter
    def id_rr(self, id_rr):
        """Sets the id_rr of this TireSet.

        Unique identifier corresponding to the rear right tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_rr: The id_rr of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_rr = id_rr

    @property
    def id_rl(self):
        """Gets the id_rl of this TireSet.  # noqa: E501

        Unique identifier corresponding to the rear left tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_rl of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_rl

    @id_rl.setter
    def id_rl(self, id_rl):
        """Sets the id_rl of this TireSet.

        Unique identifier corresponding to the rear left tire. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_rl: The id_rl of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_rl = id_rl

    @property
    def mounting_direction_fl(self):
        """Gets the mounting_direction_fl of this TireSet.  # noqa: E501

        Mounting direction of the front left tire in the rim  # noqa: E501

        :return: The mounting_direction_fl of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._mounting_direction_fl

    @mounting_direction_fl.setter
    def mounting_direction_fl(self, mounting_direction_fl):
        """Sets the mounting_direction_fl of this TireSet.

        Mounting direction of the front left tire in the rim  # noqa: E501

        :param mounting_direction_fl: The mounting_direction_fl of this TireSet.  # noqa: E501
        :type: str
        """
        allowed_values = ["Forward", "Reverse"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mounting_direction_fl not in allowed_values):
            raise ValueError(
                "Invalid value for `mounting_direction_fl` ({0}), must be one of {1}"  # noqa: E501
                .format(mounting_direction_fl, allowed_values)
            )

        self._mounting_direction_fl = mounting_direction_fl

    @property
    def mounting_direction_fr(self):
        """Gets the mounting_direction_fr of this TireSet.  # noqa: E501

        Mounting direction of the front right tire in the rim  # noqa: E501

        :return: The mounting_direction_fr of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._mounting_direction_fr

    @mounting_direction_fr.setter
    def mounting_direction_fr(self, mounting_direction_fr):
        """Sets the mounting_direction_fr of this TireSet.

        Mounting direction of the front right tire in the rim  # noqa: E501

        :param mounting_direction_fr: The mounting_direction_fr of this TireSet.  # noqa: E501
        :type: str
        """
        allowed_values = ["Forward", "Reverse"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mounting_direction_fr not in allowed_values):
            raise ValueError(
                "Invalid value for `mounting_direction_fr` ({0}), must be one of {1}"  # noqa: E501
                .format(mounting_direction_fr, allowed_values)
            )

        self._mounting_direction_fr = mounting_direction_fr

    @property
    def mounting_direction_rl(self):
        """Gets the mounting_direction_rl of this TireSet.  # noqa: E501

        Mounting direction of the rear left tire in the rim  # noqa: E501

        :return: The mounting_direction_rl of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._mounting_direction_rl

    @mounting_direction_rl.setter
    def mounting_direction_rl(self, mounting_direction_rl):
        """Sets the mounting_direction_rl of this TireSet.

        Mounting direction of the rear left tire in the rim  # noqa: E501

        :param mounting_direction_rl: The mounting_direction_rl of this TireSet.  # noqa: E501
        :type: str
        """
        allowed_values = ["Forward", "Reverse"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mounting_direction_rl not in allowed_values):
            raise ValueError(
                "Invalid value for `mounting_direction_rl` ({0}), must be one of {1}"  # noqa: E501
                .format(mounting_direction_rl, allowed_values)
            )

        self._mounting_direction_rl = mounting_direction_rl

    @property
    def mounting_direction_rr(self):
        """Gets the mounting_direction_rr of this TireSet.  # noqa: E501

        Mounting direction of the rear right tire in the rim  # noqa: E501

        :return: The mounting_direction_rr of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._mounting_direction_rr

    @mounting_direction_rr.setter
    def mounting_direction_rr(self, mounting_direction_rr):
        """Sets the mounting_direction_rr of this TireSet.

        Mounting direction of the rear right tire in the rim  # noqa: E501

        :param mounting_direction_rr: The mounting_direction_rr of this TireSet.  # noqa: E501
        :type: str
        """
        allowed_values = ["Forward", "Reverse"]  # noqa: E501
        if (self._configuration.client_side_validation and
                mounting_direction_rr not in allowed_values):
            raise ValueError(
                "Invalid value for `mounting_direction_rr` ({0}), must be one of {1}"  # noqa: E501
                .format(mounting_direction_rr, allowed_values)
            )

        self._mounting_direction_rr = mounting_direction_rr

    @property
    def last_update_date_utc(self):
        """Gets the last_update_date_utc of this TireSet.  # noqa: E501

        Last updated utc date time. This field is automatically filled by the system.  # noqa: E501

        :return: The last_update_date_utc of this TireSet.  # noqa: E501
        :rtype: datetime
        """
        return self._last_update_date_utc

    @last_update_date_utc.setter
    def last_update_date_utc(self, last_update_date_utc):
        """Sets the last_update_date_utc of this TireSet.

        Last updated utc date time. This field is automatically filled by the system.  # noqa: E501

        :param last_update_date_utc: The last_update_date_utc of this TireSet.  # noqa: E501
        :type: datetime
        """

        self._last_update_date_utc = last_update_date_utc

    @property
    def last_update_user(self):
        """Gets the last_update_user of this TireSet.  # noqa: E501

        Name of the last user who updated the data. This field is automatically filled by the system.  # noqa: E501

        :return: The last_update_user of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._last_update_user

    @last_update_user.setter
    def last_update_user(self, last_update_user):
        """Sets the last_update_user of this TireSet.

        Name of the last user who updated the data. This field is automatically filled by the system.  # noqa: E501

        :param last_update_user: The last_update_user of this TireSet.  # noqa: E501
        :type: str
        """

        self._last_update_user = last_update_user

    @property
    def tire_set_color(self):
        """Gets the tire_set_color of this TireSet.  # noqa: E501

        The tireset color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :return: The tire_set_color of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._tire_set_color

    @tire_set_color.setter
    def tire_set_color(self, tire_set_color):
        """Sets the tire_set_color of this TireSet.

        The tireset color. You must enter a ARGB hex value : #FF12EE33  # noqa: E501

        :param tire_set_color: The tire_set_color of this TireSet.  # noqa: E501
        :type: str
        """

        self._tire_set_color = tire_set_color

    @property
    def heating_time_of_use(self):
        """Gets the heating_time_of_use of this TireSet.  # noqa: E501

        Time of the day when the tires are used. The date part will automatically replaced with the date of the day.  Here is an example : 2019-01-07T12:30:00.000Z  # noqa: E501

        :return: The heating_time_of_use of this TireSet.  # noqa: E501
        :rtype: datetime
        """
        return self._heating_time_of_use

    @heating_time_of_use.setter
    def heating_time_of_use(self, heating_time_of_use):
        """Sets the heating_time_of_use of this TireSet.

        Time of the day when the tires are used. The date part will automatically replaced with the date of the day.  Here is an example : 2019-01-07T12:30:00.000Z  # noqa: E501

        :param heating_time_of_use: The heating_time_of_use of this TireSet.  # noqa: E501
        :type: datetime
        """

        self._heating_time_of_use = heating_time_of_use

    @property
    def heating_duration(self):
        """Gets the heating_duration of this TireSet.  # noqa: E501

        Heating duration in seconds  # noqa: E501

        :return: The heating_duration of this TireSet.  # noqa: E501
        :rtype: float
        """
        return self._heating_duration

    @heating_duration.setter
    def heating_duration(self, heating_duration):
        """Sets the heating_duration of this TireSet.

        Heating duration in seconds  # noqa: E501

        :param heating_duration: The heating_duration of this TireSet.  # noqa: E501
        :type: float
        """

        self._heating_duration = heating_duration

    @property
    def heating_temperature(self):
        """Gets the heating_temperature of this TireSet.  # noqa: E501

        Heating temperature to use  # noqa: E501

        :return: The heating_temperature of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._heating_temperature

    @heating_temperature.setter
    def heating_temperature(self, heating_temperature):
        """Sets the heating_temperature of this TireSet.

        Heating temperature to use  # noqa: E501

        :param heating_temperature: The heating_temperature of this TireSet.  # noqa: E501
        :type: str
        """

        self._heating_temperature = heating_temperature

    @property
    def heating_oven(self):
        """Gets the heating_oven of this TireSet.  # noqa: E501


        :return: The heating_oven of this TireSet.  # noqa: E501
        :rtype: StringWithFontStyle
        """
        return self._heating_oven

    @heating_oven.setter
    def heating_oven(self, heating_oven):
        """Sets the heating_oven of this TireSet.


        :param heating_oven: The heating_oven of this TireSet.  # noqa: E501
        :type: StringWithFontStyle
        """

        self._heating_oven = heating_oven

    @property
    def heating_engineer_comment(self):
        """Gets the heating_engineer_comment of this TireSet.  # noqa: E501


        :return: The heating_engineer_comment of this TireSet.  # noqa: E501
        :rtype: StringWithFontStyle
        """
        return self._heating_engineer_comment

    @heating_engineer_comment.setter
    def heating_engineer_comment(self, heating_engineer_comment):
        """Sets the heating_engineer_comment of this TireSet.


        :param heating_engineer_comment: The heating_engineer_comment of this TireSet.  # noqa: E501
        :type: StringWithFontStyle
        """

        self._heating_engineer_comment = heating_engineer_comment

    @property
    def heating_time_on_heat(self):
        """Gets the heating_time_on_heat of this TireSet.  # noqa: E501

        Starting time of the tires heating. The date part will automatically replaced with the date of the day.  Here is an example : 2019-01-07T12:30:00.000Z  # noqa: E501

        :return: The heating_time_on_heat of this TireSet.  # noqa: E501
        :rtype: datetime
        """
        return self._heating_time_on_heat

    @heating_time_on_heat.setter
    def heating_time_on_heat(self, heating_time_on_heat):
        """Sets the heating_time_on_heat of this TireSet.

        Starting time of the tires heating. The date part will automatically replaced with the date of the day.  Here is an example : 2019-01-07T12:30:00.000Z  # noqa: E501

        :param heating_time_on_heat: The heating_time_on_heat of this TireSet.  # noqa: E501
        :type: datetime
        """

        self._heating_time_on_heat = heating_time_on_heat

    @property
    def heating_tire_comment(self):
        """Gets the heating_tire_comment of this TireSet.  # noqa: E501


        :return: The heating_tire_comment of this TireSet.  # noqa: E501
        :rtype: StringWithFontStyle
        """
        return self._heating_tire_comment

    @heating_tire_comment.setter
    def heating_tire_comment(self, heating_tire_comment):
        """Sets the heating_tire_comment of this TireSet.


        :param heating_tire_comment: The heating_tire_comment of this TireSet.  # noqa: E501
        :type: StringWithFontStyle
        """

        self._heating_tire_comment = heating_tire_comment

    @property
    def heating_action_after_use(self):
        """Gets the heating_action_after_use of this TireSet.  # noqa: E501

        Discribe the action to do after the use of the tire  # noqa: E501

        :return: The heating_action_after_use of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._heating_action_after_use

    @heating_action_after_use.setter
    def heating_action_after_use(self, heating_action_after_use):
        """Sets the heating_action_after_use of this TireSet.

        Discribe the action to do after the use of the tire  # noqa: E501

        :param heating_action_after_use: The heating_action_after_use of this TireSet.  # noqa: E501
        :type: str
        """

        self._heating_action_after_use = heating_action_after_use

    @property
    def heating_done(self):
        """Gets the heating_done of this TireSet.  # noqa: E501

        Specify whether the heating is completed or not  # noqa: E501

        :return: The heating_done of this TireSet.  # noqa: E501
        :rtype: bool
        """
        return self._heating_done

    @heating_done.setter
    def heating_done(self, heating_done):
        """Sets the heating_done of this TireSet.

        Specify whether the heating is completed or not  # noqa: E501

        :param heating_done: The heating_done of this TireSet.  # noqa: E501
        :type: bool
        """

        self._heating_done = heating_done

    @property
    def id_spare1(self):
        """Gets the id_spare1 of this TireSet.  # noqa: E501

        Unique identifier corresponding to the spare tire 1. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_spare1 of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_spare1

    @id_spare1.setter
    def id_spare1(self, id_spare1):
        """Sets the id_spare1 of this TireSet.

        Unique identifier corresponding to the spare tire 1. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_spare1: The id_spare1 of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_spare1 = id_spare1

    @property
    def id_spare2(self):
        """Gets the id_spare2 of this TireSet.  # noqa: E501

        Unique identifier corresponding to the spare tire 2. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :return: The id_spare2 of this TireSet.  # noqa: E501
        :rtype: str
        """
        return self._id_spare2

    @id_spare2.setter
    def id_spare2(self, id_spare2):
        """Sets the id_spare2 of this TireSet.

        Unique identifier corresponding to the spare tire 2. The tire must exists in the event linked to the tire set.  Enter the empty identifier (00000000-0000-0000-0000-000000000000) to unset the tire.  # noqa: E501

        :param id_spare2: The id_spare2 of this TireSet.  # noqa: E501
        :type: str
        """

        self._id_spare2 = id_spare2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(TireSet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TireSet):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TireSet):
            return True

        return self.to_dict() != other.to_dict()
